<?php
namespace BotGuard;

class SettingsTab extends BaseISPFunction {

	public function execute(string $func, string $action = '') {
		// check that user has administrator rights
		if (!isset($_SERVER['AUTH_LEVEL']) || intval($_SERVER['AUTH_LEVEL']) == 0 || intval($_SERVER['AUTH_LEVEL']) < 29) {
			exit(403);
		}

		if (isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] == 'POST') {
			$this->save($func, $action);
		} else {
			$this->get($func, $action);
		}
	}

	private function get(string $func, string $action = '', string $body = '') {
		$api_key = htmlspecialchars($this->settings['botguard-api-key']);
		$primary_server = htmlspecialchars($this->settings['botguard-primary-server']);
		$secondary_server = htmlspecialchars($this->settings['botguard-secondary-server']);
		$mitigation_humans = isset($this->settings['options']['mitigation_humans']) ? $this->settings['options']['mitigation_humans'] : 'grant';
		$mitigation_search_engines = isset($this->settings['options']['mitigation_search_engines']) ? $this->settings['options']['mitigation_search_engines'] : 'grant';
		$mitigation_emulated_humans = isset($this->settings['options']['mitigation_emulated_humans']) ? $this->settings['options']['mitigation_emulated_humans'] : 'grant';
		$mitigation_security_issues = isset($this->settings['options']['mitigation_security_issues']) ? $this->settings['options']['mitigation_security_issues'] : 'grant';
		$mitigation_social_networks = isset($this->settings['options']['mitigation_social_networks']) ? $this->settings['options']['mitigation_social_networks'] : 'grant';
		$mitigation_content_scrapers = isset($this->settings['options']['mitigation_content_scrapers']) ? $this->settings['options']['mitigation_content_scrapers'] : 'grant';
		$mitigation_suspicious_behaviour = isset($this->settings['options']['mitigation_suspicious_behaviour']) ? $this->settings['options']['mitigation_suspicious_behaviour'] : 'grant';
		$mitigation_services_and_payments = isset($this->settings['options']['mitigation_services_and_payments']) ? $this->settings['options']['mitigation_services_and_payments'] : 'grant';

		echo <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<doc lang="{$this->lang}" themename="{$this->theme}" func="{$func}" action="{$action}">
	{$body}
	<slist name="mitigation_humans">
		<val key="deny">Deny access</val>
		<val key="grant">Grant access</val>
	</slist>
	<slist name="mitigation_search_engines">
		<val key="deny">Deny access</val>
		<val key="grant">Grant access</val>
	</slist>
	<slist name="mitigation_emulated_humans">
		<val key="deny">Deny access</val>
		<val key="grant">Grant access</val>
	</slist>
	<slist name="mitigation_security_issues">
		<val key="deny">Deny access</val>
		<val key="grant">Grant access</val>
	</slist>
	<slist name="mitigation_social_networks">
		<val key="deny">Deny access</val>
		<val key="grant">Grant access</val>
	</slist>
	<slist name="mitigation_content_scrapers">
		<val key="deny">Deny access</val>
		<val key="grant">Grant access</val>
	</slist>
	<slist name="mitigation_suspicious_behaviour">
		<val key="deny">Deny access</val>
		<val key="grant">Grant access</val>
	</slist>
	<slist name="mitigation_services_and_payments">
		<val key="deny">Deny access</val>
		<val key="grant">Grant access</val>
	</slist>
	<api_key>{$api_key}</api_key>
	<primary_server>{$primary_server}</primary_server>
	<secondary_server>{$secondary_server}</secondary_server>
	<mitigation_humans>{$mitigation_humans}</mitigation_humans>
	<mitigation_search_engines>{$mitigation_search_engines}</mitigation_search_engines>
	<mitigation_emulated_humans>{$mitigation_emulated_humans}</mitigation_emulated_humans>
	<mitigation_security_issues>{$mitigation_security_issues}</mitigation_security_issues>
	<mitigation_social_networks>{$mitigation_social_networks}</mitigation_social_networks>
	<mitigation_content_scrapers>{$mitigation_content_scrapers}</mitigation_content_scrapers>
	<mitigation_suspicious_behaviour>{$mitigation_suspicious_behaviour}</mitigation_suspicious_behaviour>
	<mitigation_services_and_payments>{$mitigation_services_and_payments}</mitigation_services_and_payments>
</doc>
XML;
	}

	private function save(string $func, string $action = '') {
		if (empty($_SERVER['PARAM_api_key']) || empty($_SERVER['PARAM_primary_server']) || empty($_SERVER['PARAM_secondary_server'])) {
			exit(400);
		}

		$this->settings = [
			'botguard-api-key' => $_SERVER['PARAM_api_key'],
			'botguard-primary-server' => $_SERVER['PARAM_primary_server'],
			'botguard-secondary-server' => $_SERVER['PARAM_secondary_server'],
			'options' => [
				'mitigation_humans' => $_SERVER['PARAM_mitigation_humans'],
				'mitigation_search_engines' => $_SERVER['PARAM_mitigation_search_engines'],
				'mitigation_emulated_humans' => $_SERVER['PARAM_mitigation_emulated_humans'],
				'mitigation_security_issues' => $_SERVER['PARAM_mitigation_security_issues'],
				'mitigation_social_networks' => $_SERVER['PARAM_mitigation_social_networks'],
				'mitigation_content_scrapers' => $_SERVER['PARAM_mitigation_content_scrapers'],
				'mitigation_suspicious_behaviour' => $_SERVER['PARAM_mitigation_suspicious_behaviour'],
				'mitigation_services_and_payments' => $_SERVER['PARAM_mitigation_services_and_payments']
			]
		];
		@file_put_contents($this->apache_config_dir . '/botguard.json', json_encode($this->settings, JSON_INVALID_UTF8_IGNORE | JSON_PRETTY_PRINT));

		// apply apache config
		if ($this->apache_config_dir) {
			$config = @file_get_contents($this->apache_config_dir . '/botguard.conf');
			if (!$config) {
				$banners .= '<banner id="no_botguard_apache_module" status="2" />';
			} else {
				$config = preg_replace('/.*BotguardCheck ".*"/', "\tBotguardCheck off", $config);
				$config = preg_replace('/.*BotguardPrimaryServer ".*"/', "\tBotguardPrimaryServer \"{$_SERVER['PARAM_primary_server']}\"", $config);
				$config = preg_replace('/.*BotguardSecondaryServer ".*"/', "\tBotguardSecondaryServer \"{$_SERVER['PARAM_secondary_server']}\"", $config);
				@file_put_contents($this->apache_config_dir . '/botguard.conf', $config);
				if (@shell_exec("service {$this->apache_service} reload && echo -n OK") == 'OK') {
					$banners .= '<banner id="apache_reloaded" status="3" />';
				} else {
					$banners .= '<banner id="apache_reload_failed" status="1" />';
				}
			}
		}

		// apply nginx config
		if ($this->nginx_config_dir) {
			$config = @file_get_contents($this->nginx_config_dir . '/50-botguard.conf');
			if (!$config) {
				$banners .= '<banner id="no_botguard_nginx_module" status="2" />';
			} else {
				$config = preg_replace('/.*aio threads;/', "aio threads;", $config);
				$config = preg_replace('/.*botguard_check .*;/', "botguard_check off;", $config);
				$config = preg_replace('/.*botguard_primary_server .*;/', "botguard_primary_server \"{$_SERVER['PARAM_primary_server']}\";", $config);
				$config = preg_replace('/.*botguard_secondary_server .*;/', "botguard_secondary_server \"{$_SERVER['PARAM_secondary_server']}\";", $config);
				@file_put_contents($this->nginx_config_dir . '/50-botguard.conf', $config);
				if (@shell_exec("service {$this->nginx_service} reload && echo -n OK") == 'OK') {
					$banners .= '<banner id="nginx_reloaded" status="3" />';
				} else {
					$banners .= '<banner id="nginx_reload_failed" status="1" />';
				}
			}
		}

		$this->get($func, $action, $banners);
	}

}
