<?php
namespace BotGuard;

use BotGuard\BotGuard;

class WebDomainTab extends BaseISPFunction {

	public function execute(string $func, string $action = '') {
		if (empty($this->settings['botguard-api-key'])) {
			$this->error('no_api_key', $func, $action);
			exit(400);
		}
		if (!isset($_SERVER['EVENT_TYPE']) || $_SERVER['EVENT_TYPE'] != 'after') {
			exit(400);
		}

		if (isset($_SERVER['PARAM_botguard_enabled'])) {
			$this->save($func, $action);
		} else {
			$this->get($func, $action);
		}

	}

	private function get(string $func, string $action = '') {
		$enabled = 'on';
		if (isset($_SERVER['PARAM_elid'])) {
			$domains = $this->getDomains();
			if (isset($domains[$this->punycode($_SERVER['PARAM_elid'])])) {
				$owner = $domains[$this->punycode($_SERVER['PARAM_elid'])]->owner;
				// check if there is nginx config
				$path = realpath($this->nginx_vhosts_dir . '/' . $owner . '/' . $this->punycode($_SERVER['PARAM_elid']) . '.conf');
				if (strpos($path, $this->nginx_vhosts_dir . '/' . $owner) !== 0) {
					exit(403);
				}
				$nginx_config = @file_get_contents($path);
				if ($nginx_config) {
					if (preg_match('/^\s+botguard_check on;/m', $nginx_config)) {
						$enabled = 'on';
					} else {
						$enabled = 'off';
					}
				} else {
					// if not, check the apache config
					$path = realpath($this->apache_vhosts_dir . '/' . $owner . '/' . $this->punycode($_SERVER['PARAM_elid']));
					if (strpos($path, $this->apache_vhosts_dir . '/' . $owner) !== 0) {
						exit(403);
					}
					$apache_config = @file_get_contents($path);
					if ($apache_config) {
						if (strpos($apache_config, 'BotguardCheck on') > 0) {
							$enabled = 'on';
						} else {
							$enabled = 'off';
						}
					}
				}
			}
		}

		echo <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<doc lang="{$this->lang}" themename="{$this->theme}" func="{$func}" action="{$action}">
<botguard_enabled>{$enabled}</botguard_enabled>
</doc>
XML;
	}

	private function save(string $func, string $action = '') {
		$enabled = 'off';
		if (isset($_SERVER['PARAM_elid'])) {
			$botguard = new BotGuard($this->settings['botguard-api-key']);
			if (isset($_SERVER['PARAM_botguard_enabled']) && $_SERVER['PARAM_botguard_enabled'] == 'on') {
				$enabled = 'on';
				// register web site
				try {
					$botguard->addDomain($this->punycode($_SERVER['PARAM_elid']), $this->settings['options']);
				} catch (\Exception $ex) { };
			}
		}
		echo <<<XML
<?xml version="1.0" encoding="UTF-8"?>
<doc lang="{$this->lang}" themename="{$this->theme}" func="{$func}" action="{$action}">
<botguard_enabled>{$enabled}</botguard_enabled>
</doc>
XML;
	}
}
